function [t,y] =  jingxi
% 定义微分方程
%y1:Tm y2:Tp y3:Pm y4:Pp y5:Am y6:ATm y7 Gm y8:Gp y9:Ga
function dydt = cell_eq(t,y)

    G1=131;
    G2=131;
    G3=131;
    KMt=0.0006;
    KMp=0.640;
    kT=2.81;
    kp=1.52;
    aT=0.02;
    aP=0.02;
    KMT=0.001;
    KMP=0.0013;
    nT=1.88;
    nP=2.75;
    k1=431;
    k2=0.0002;
    k3=0.90;
    kDTm=0.0126;
    kDAm=0.0365;
    kDPm=0.0437;
    kDGm=0.0609;
    kTL=1.453;
    kDTp=0.0553;
    kDPp=0.0955;
    kDGp=0.0775;
    fV=0.00000185;
    fF=15.01;
    kDTc=0.0012;
    A=0.883;
    kIAS=0.997;
    kMTC=0.001;
    
    Tcext=0;
    Tc=0;
    PI=0;

Phis=(1-y(10)/G1)/(1+kMTC-y(10)/G1);
Phia=(1-y(11)/G1)/(1+kMTC-y(11)/G1);
    b=kIAS/(kIAS+y(11)/G1);

    dydt = zeros(12,1);
    Ta=y(2)*(1-y(12)/(KMt+y(12)));
    Pa=y(4)*(1-PI/(KMp+PI));
    rT=kT*fV*(aT+(1-aT)*power(Ta,nT)/(KMT+power(Ta,nT)));
    rp=1*kp*fV*(aP+(1-aP)*power(Pa,nP)/(KMP+power(Pa,nP)));

    dydt(1) = kT/(1-A)*b*y(10)-k1*y(5)*y(1)+y(6)*(k2+kDAm)-kDTm*y(1); 
    dydt(2) = kTL*y(1)-kDTp*y(2);
    dydt(3) = G2*rT-kDPm*y(3);%
    dydt(4) = kTL*y(3)-kDPp*y(4);
    dydt(5) = kT/A*y(11)-k1*y(5)*y(1)+y(6)*(k2+kDTm)-kDAm*y(5);
    dydt(6) = k1*y(5)*y(1)-y(6)*(k2+kDTm+kDAm);
    dydt(7) = G3*rT-kDGm*y(7);
    dydt(8) = kTL*y(7)-(k3+kDGp)*y(8);
    dydt(9) = k3*y(8)-kDGp*y(9);
    dydt(10)= G1*rT*Phis/A-kT*y(10)/(1-A);
    dydt(11)= G1*rp*Phia/(1-A)-kT*y(11)/A;
    dydt(12)= kDTc*(Tcext-y(12));

end

% 定义初始条件
y0 = [0; 0; 0; 0; 0; 0; 0; 0; 0;0;0;0];

% 定义时间范围
tspan = [0:2.5: 1000];

% 解决微分方程
[t,y] = ode45(@cell_eq,tspan,y0);

% 绘制结果
%plot(t,y(:,1))
%,t,y(:,7),'k',t,y(:,8),'b',t,y(:,9),'g'
%'Gm','Gp','Ga'

plot(t,y(:,1),'r',t,y(:,2),'g',t,y(:,3),'b',t,y(:,4),'c',t,y(:,5),'m',t,y(:,6),'y');
%plot(t,y(:,1),'r',t,y(:,3),'g',t,y(:,6));

xlabel('Time');
ylabel('Cell Concentration');

%legend('Tm','Pm','ATm')
legend('Tm','Tp','Pm','Pp','Am','ATm');
end