function [yhat,meanCycle] = Q2TriModel3fitNoStand(para, X,tspan)


    KDXm = para(1)
    KDXP = para(2)
    KDRm = para(3)
    KDRP = para(4)
    KDTm = para(7)
    KDTP = para(8)
    Ktx  = para(11)
    KT   = para(12)
    nT   = para(13)
    nX   = para(14)
    G0X  = para(15)
    G0T  = para(17)
    G0R  = para(18)
    KDYm = para(19)
    KDZm = para(20)
    KDYP = para(21)
    KDZP = para(22)
    KTLX = para(23)
    KTLY = para(24)
    KTLZ = para(25)
    KTLR = para(26)
    KTLT = para(28)
    Kty  = para(29)
    Ktz  = para(30)
    KtR  = para(31)
    fVx  = para(32)
    fVy  = para(33)
    fVz  = para(34)
    fVR  = para(36)
    BZ   = para(37)
    BX   = para(38)
    nY   = para(40)
    nZ   = para(41)
    Ax   = para(42)
    Ay   = para(43)
    Az   = para(44)
    AR   = para(45)
    G0Y  = para(47)
    G0Z  = para(48)
    r0   = para(49)

    function dydt = cell_eq(~, y)

        Xm = y(1);
        Xp = y(2);
        Ym = y(3);
        Yp = y(4);
        Zm = y(5);
        Zp = y(6);
        Rm = y(7);
        Rp = y(8);
        Tm = y(9);
        Tp = y(10);

        fTX = (power(Tp, nT)) / (KT + power(Tp, nT) + BZ * power(Zp, nZ));
        fTY = (power(Tp, nT)) / (KT + power(Tp, nT) + BX * power(Xp, nX));
        fTZ = (power(Tp, nT)) / (KT + power(Tp, nT) + BZ * power(Yp, nY));

        fTR  = fTY;

        rX = Ktx * [Ax + (1 - Ax) * fTX] * fVx;
        rY = Kty * [Ay + (1 - Ay) * fTY] * fVy;
        rZ = Ktz * [Az + (1 - Az) * fTZ] * fVz;
        rR = KtR * [AR + (1 - AR) * fTR] * fVR;

        dXmdt = G0X * rX - KDXm * Xm;
        dXpdt = KTLX * Xm - KDXP * Xp;
        dYmdt = G0Y * rY - KDYm * Ym;
        dYpdt = KTLY * Ym - KDYP * Yp;
        dZmdt = G0Z * rZ - KDZm * Zm;
        dZpdt = KTLZ * Zm - KDZP * Zp;
        dRmdt = G0R * rR - KDRm * Rm;
        dRpdt = KTLR * Rm - KDRP * Rp;
        dTmdt = G0T * r0 - KDTm * Tm;
        dTpdt = KTLT * Tm - KDTP * Tp;

        dydt = [dXmdt; dXpdt; dYmdt; dYpdt; dZmdt; dZpdt; dRmdt; dRpdt;dTmdt; dTpdt];
    end

    [t, y] = ode45(@cell_eq, tspan, X);

    y_BACK = y(:, 1:10);
    y_BACK(:,3:6) = [];
    % y_BACK = zscore(y_BACK);
    % y = zscore(y);

    plot(t, y(:, 1), t, y(:, 2), t, y(:, 3), t, y(:, 4), t, y(:, 5), t, y(:, 6), t, y(:, 7), t, y(:, 8), 'LineWidth', 1);
    legend('Xm', 'Xp', 'Ym', 'Yp', 'Zm', 'Zp', 'Rm', 'Rp')
    % 1-1
    % 2-2
    % 7-3
    % 8-4
    % 9-5
    % 10-6
    % 11-7
    % 12-8

    [pks,locs] = findpeaks(y_BACK(:,1));
    cycles = diff(t(locs));
    meanCycle = mean(cycles)

    saveas(1, 'fig.jpg')
    hold off

    yhat = y;

end
