% y1 Xm
% y2 Xp
% y3 Rm
% y4 Rp
% y5 Lm
% y6 Lp
% y7 Tm
% y8 Tp

% para:
% para(1) KDXm
% para(2) KDXP
% para(3) KDRm
% para(4) KDRP
% para(5) KDLm
% para(6) KDLP
% para(7) KDTm
% para(8) KDTP

function [yhat] = Q2ModelV3fitFunPro4(para,X)

KDXm = para(1)
KDXP = para(2)
KDRm = para(3)
KDRP = para(4)
KDLm = para(5)
KDLP = para(6)
KDTm = para(7)
KDTP = para(8)
KLA = para(9)
KTL = para(10)
KTX= para(11)
KIX= para(12)
fV=  para(13)
Kt=  para(14)
nT=  para(15)
nX=  para(16)
G0x = para(17)
G0L = para(18)
G0T = para(19)
G0R = para(20)
A=0.005;

beta=KTX/KIX;

    function dydt = cell_eq(~,y)

        dydt = zeros(8,1);

        Xm = y(1);
        Xp = y(2);
        Rm = y(3);
        Rp = y(4);
        Lm = y(5);
        Lp = y(6);
        Tm = y(7);
        Tp = y(8);

        fT = (power(y(8),nT))/(KTX+power(y(8),nT)+beta*power(y(2),nX));

        r1 = Kt*(A+(1-A)*fT)*fV;

        dydt(1) = G0x*r1-KDXm*Xm;
        dydt(2) = KTL*Xm-KDXP*Xp;
        dydt(3) = G0R*r1-KDRm*Rm;
        dydt(4) = KTL*Rm-KDRP*Rp;
        dydt(5) = G0L*r1-KDLm*Lm;
        dydt(6) = KTL*Lm-(KDLP+KLA)*Lp;
        dydt(7) = G0T*r1-KDTm*Tm;
        dydt(8) = KTL*Tm-KDTP*Tp;
    end

tspan = [0:0.1:3000];

[t,y] = ode45(@cell_eq,tspan,X);

y_BACK = y(:,1:8);
y_BACK=zscore(y_BACK);
y = y_BACK;

plot(t,y(:,1),t,y(:,2),t,y(:,3),t,y(:,4),t,y(:,5),t,y(:,6),t,y(:,7),t,y(:,8),'LineWidth',1)
legend('Xm','Xp','Rm','Rp','Lm','Lp','Tm','Tp')
saveas(1,'fig.jpg')
hold off

yhat = y(:,4);

end
