function jingxi
% 定义微分方程
%y1:Xm y2:Xp y3:Rm y4:Rp y5:Lm y6:Lp y7:Tm y8:Tp y9:G1x y10:GRx y11:GLx
%y12:G1 y13:GRT y14:GLT
    KDXm=0.0089;
    KDRm=0.0845;
    KDLm=0.0120;            %影响振幅
    KDTm=0.0455;            %影响振幅
    
    KDXP=0.0244;
    KDRP=0.0549;            %影响振幅
    KDLP=0.0191;
    KDTP=0.0159;            %影响振幅

    kTX=0.0221;             %影响振幅
    kIX=0.0378;

function dydt = cell_eq(t,y)

    G0x=100;
    G0R=100;
    G0L=100;
    G0T=100;
    r2=30*1.85*0.000001;
    KLA=0.90;
    fV=1.85*0.000001;
    Kt=30;
    
    nT=2;
    nX=2;
    KTL=0.02;

   
    
    dydt = zeros(14,1);
    beta=kTX/kIX;

    fX=(beta*power(y(2),nX))/(kTX+power(y(8),nT)+beta*power(y(2),nX));
    fT=(power(y(8),nT))/(kTX+power(y(8),nT)+beta*power(y(2),nX));
    
    y(9)=G0x*fX;
    y(12)=G0x*fT;

    y(10)=G0R*fX;
    y(13)=G0R*fT;

    y(11)=G0L*fX;
    y(14)=G0L*fT;

    r1=Kt*fT*fV;
    dydt(1)=G0x*r1-KDXm*y(1);
    dydt(2)=KTL*y(1)-KDXP*(y(2)+y(9)+y(10)+y(11))-dydt(9)-dydt(10)-dydt(11);
    dydt(3)=G0R*r1-KDRm*y(3);
    dydt(4)=KTL*y(3)-KDRP*y(4);
    dydt(5)=G0L*r1-KDLm*y(5);
    dydt(6)=KTL*y(5)-(KDLP+KLA)*y(6);
    dydt(7)=G0T*r2-KDTm*y(7);
    dydt(8)=KTL*y(7)-KDTP*(y(8)+y(12)+y(13)+y(14))-dydt(12)-dydt(13)-dydt(14);
end

% 定义初始条件
y0 = [0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0; 0];

% 定义时间范围
tspan = [0 2000];

% 解决微分方程
[t,y] = ode45(@cell_eq,tspan,y0);

% 绘制结果
%plot(t,y(:,1))
%,t,y(:,7),'k',t,y(:,8),'b',t,y(:,9),'g'
%'Gm','Gp','Ga'

%plot(t,y(:,1),'r',t,y(:,2),'g',t,y(:,3),'b',t,y(:,4),'c',t,y(:,5),'m',t,y(:,6),'y');
%plot(t,y(:,1),'r',t,y(:,3),'g',t,y(:,6));
plot(t,y(:,6));

xlabel('Time');
ylabel('Cell Concentration');

%legend('Tm','Pm','ATm')
%legend('Tm','Tp','Pm','Pp','Am','ATm');
legend("Rp");
    KDXm
    KDRm
    KDLm
    KDTm
    
    KDXP
    KDRP
    KDLP
    KDTP

    kTX
    kIX
end