function jingxi
% 定义微分方程
%y1:Xm y2:Xp y3:Rm y4:Rp y5:Lm y6:Lp y7:Tm y8:Tp
function dydt = cell_eq(t,y)

    G0x=150;
    G0R=150;
    G0L=150;
    G0T=150;
    r2=5.2*0.000001;
    KLA=0.90;
    fV=1.85*0.000001;
    Kt=2.81;
    
    nT=2;
    nX=2;
    KTL=1.5;

    KDXm=0.04;
    KDRm=0.06;
    KDLm=0.06;
    KDTm=0.01;
    
    KDXP=0.1;
    KDRP=0.08;
    KDLP=0.08;
    KDTP=0.05;

    kTX=0.001;
    kIX=0.0013;

    dydt = zeros(8,1);

    beta=kTX/kIX;

    fX=(beta*power(y(2),nX))/(kTX+power(y(8),nT)+beta*power(y(2),nX));
    fT=(power(y(8),nT))/(kTX+power(y(8),nT)+beta*power(y(2),nX));
    
    G1x=G0x*fX;
    G1=G0x*fT;

    GRx=G0R*fX;
    GRT=G0R*fT;

    GLx=G0L*fX;
    GLT=G0L*fT;

    r1=Kt*fT*fV;
    dydt(1)=G0x*r1-KDXm*y(1);
    dydt(2)=KTL*y(1)-KDXP*(y(2)+G1x+GRx+GLx)-dG1xdt-dGRxdt-dGLxdt;
    dydt(3)=G0R*r1-KDRm*y(3);
    dydt(4)=KTL*y(3)-KDRP*y(4);
    dydt(5)=G0L*r1-KDLm*y(5);
    dydt(6)=KTL*y(5)-(KDRP+KLA)*y(6);
    dydt(7)=G0T*r2-KDTm*y(7);
    dydt(8)=KTL*y(7)-KDTP*(y(8)+G1+GRT+GLT)-dG1dt-dGRTdt-dGLTdt;
end

% 定义初始条件
y0 = [0; 0; 0; 0; 0; 0; 0; 0];

% 定义时间范围
tspan = [0 5000];

% 解决微分方程
[t,y] = ode45(@cell_eq,tspan,y0);

% 绘制结果
%plot(t,y(:,1))
%,t,y(:,7),'k',t,y(:,8),'b',t,y(:,9),'g'
%'Gm','Gp','Ga'

%plot(t,y(:,1),'r',t,y(:,2),'g',t,y(:,3),'b',t,y(:,4),'c',t,y(:,5),'m',t,y(:,6),'y');
%plot(t,y(:,1),'r',t,y(:,3),'g',t,y(:,6));
plot(t,y(:,2));

xlabel('Time');
ylabel('Cell Concentration');

%legend('Tm','Pm','ATm')
%legend('Tm','Tp','Pm','Pp','Am','ATm');
legend("Tp");
end